@@ -24,171 +24,148 @@
 
 #include "client.h"
 
-
 /* Implementation *************************************************************/
 CClient::CClient ( const quint16  iPortNumber,
+                   const quint16  iQosNumber,
                    const QString& strConnOnStartupAddress,
                    const QString& strMIDISetup,
                    const bool     bNoAutoJackConnect,
                    const QString& strNClientName,
+                   const bool     bNEnableIPv6,
                    const bool     bNMuteMeInPersonalMix ) :
-    ChannelInfo                      ( ),
-    strClientName                    ( strNClientName ),
-    Channel                          ( false ), /* we need a client channel -> "false" */
-    CurOpusEncoder                   ( nullptr ),
-    CurOpusDecoder                   ( nullptr ),
-    eAudioCompressionType            ( CT_OPUS ),
-    iCeltNumCodedBytes               ( OPUS_NUM_BYTES_MONO_LOW_QUALITY ),
-    iOPUSFrameSizeSamples            ( DOUBLE_SYSTEM_FRAME_SIZE_SAMPLES ),
-    eAudioQuality                    ( AQ_NORMAL ),
-    eAudioChannelConf                ( CC_MONO ),
-    iNumAudioChannels                ( 1 ),
-    bIsInitializationPhase           ( true ),
-    bMuteOutStream                   ( false ),
-    fMuteOutStreamGain               ( 1.0f ),
-    Socket                           ( &Channel, iPortNumber ),
-    Sound                            ( AudioCallback, this, strMIDISetup, bNoAutoJackConnect, strNClientName ),
-    iAudioInFader                    ( AUD_FADER_IN_MIDDLE ),
-    bReverbOnLeftChan                ( false ),
-    iReverbLevel                     ( 0 ),
-    iSndCrdPrefFrameSizeFactor       ( FRAME_SIZE_FACTOR_DEFAULT ),
-    iSndCrdFrameSizeFactor           ( FRAME_SIZE_FACTOR_DEFAULT ),
-    bSndCrdConversionBufferRequired  ( false ),
+    ChannelInfo(),
+    strClientName ( strNClientName ),
+    Channel ( false ), /* we need a client channel -> "false" */
+    CurOpusEncoder ( nullptr ),
+    CurOpusDecoder ( nullptr ),
+    eAudioCompressionType ( CT_OPUS ),
+    iCeltNumCodedBytes ( OPUS_NUM_BYTES_MONO_LOW_QUALITY ),
+    iOPUSFrameSizeSamples ( DOUBLE_SYSTEM_FRAME_SIZE_SAMPLES ),
+    eAudioQuality ( AQ_NORMAL ),
+    eAudioChannelConf ( CC_MONO ),
+    iNumAudioChannels ( 1 ),
+    bIsInitializationPhase ( true ),
+    bMuteOutStream ( false ),
+    fMuteOutStreamGain ( 1.0f ),
+    Socket ( &Channel, iPortNumber, iQosNumber, "", bNEnableIPv6 ),
+    Sound ( AudioCallback, this, strMIDISetup, bNoAutoJackConnect, strNClientName ),
+    iAudioInFader ( AUD_FADER_IN_MIDDLE ),
+    bReverbOnLeftChan ( false ),
+    iReverbLevel ( 0 ),
+    iInputBoost ( 1 ),
+    iSndCrdPrefFrameSizeFactor ( FRAME_SIZE_FACTOR_DEFAULT ),
+    iSndCrdFrameSizeFactor ( FRAME_SIZE_FACTOR_DEFAULT ),
+    bSndCrdConversionBufferRequired ( false ),
     iSndCardMonoBlockSizeSamConvBuff ( 0 ),
-    bFraSiFactPrefSupported          ( false ),
-    bFraSiFactDefSupported           ( false ),
-    bFraSiFactSafeSupported          ( false ),
-    eGUIDesign                       ( GD_ORIGINAL ),
-    bEnableOPUS64                    ( false ),
-    bJitterBufferOK                  ( true ),
-    bNuteMeInPersonalMix             ( bNMuteMeInPersonalMix ),
-    iServerSockBufNumFrames          ( DEF_NET_BUF_SIZE_NUM_BL ),
-    pSignalHandler                   ( CSignalHandler::getSingletonP() )
+    bFraSiFactPrefSupported ( false ),
+    bFraSiFactDefSupported ( false ),
+    bFraSiFactSafeSupported ( false ),
+    eGUIDesign ( GD_ORIGINAL ),
+    bEnableOPUS64 ( false ),
+    bJitterBufferOK ( true ),
+    bEnableIPv6 ( bNEnableIPv6 ),
+    bMuteMeInPersonalMix ( bNMuteMeInPersonalMix ),
+    iServerSockBufNumFrames ( DEF_NET_BUF_SIZE_NUM_BL ),
+    pSignalHandler ( CSignalHandler::getSingletonP() )
 {
     int iOpusError;
 
-    OpusMode = opus_custom_mode_create ( SYSTEM_SAMPLE_RATE_HZ,
-                                         DOUBLE_SYSTEM_FRAME_SIZE_SAMPLES,
-                                         &iOpusError );
+    OpusMode = opus_custom_mode_create ( SYSTEM_SAMPLE_RATE_HZ, DOUBLE_SYSTEM_FRAME_SIZE_SAMPLES, &iOpusError );
 
-    Opus64Mode = opus_custom_mode_create ( SYSTEM_SAMPLE_RATE_HZ,
-                                           SYSTEM_FRAME_SIZE_SAMPLES,
-                                           &iOpusError );
+    Opus64Mode = opus_custom_mode_create ( SYSTEM_SAMPLE_RATE_HZ, SYSTEM_FRAME_SIZE_SAMPLES, &iOpusError );
 
     // init audio encoders and decoders
-    OpusEncoderMono     = opus_custom_encoder_create ( OpusMode,   1, &iOpusError ); // mono encoder legacy
-    OpusDecoderMono     = opus_custom_decoder_create ( OpusMode,   1, &iOpusError ); // mono decoder legacy
-    OpusEncoderStereo   = opus_custom_encoder_create ( OpusMode,   2, &iOpusError ); // stereo encoder legacy
-    OpusDecoderStereo   = opus_custom_decoder_create ( OpusMode,   2, &iOpusError ); // stereo decoder legacy
+    OpusEncoderMono     = opus_custom_encoder_create ( OpusMode, 1, &iOpusError );   // mono encoder legacy
+    OpusDecoderMono     = opus_custom_decoder_create ( OpusMode, 1, &iOpusError );   // mono decoder legacy
+    OpusEncoderStereo   = opus_custom_encoder_create ( OpusMode, 2, &iOpusError );   // stereo encoder legacy
+    OpusDecoderStereo   = opus_custom_decoder_create ( OpusMode, 2, &iOpusError );   // stereo decoder legacy
     Opus64EncoderMono   = opus_custom_encoder_create ( Opus64Mode, 1, &iOpusError ); // mono encoder OPUS64
     Opus64DecoderMono   = opus_custom_decoder_create ( Opus64Mode, 1, &iOpusError ); // mono decoder OPUS64
     Opus64EncoderStereo = opus_custom_encoder_create ( Opus64Mode, 2, &iOpusError ); // stereo encoder OPUS64
     Opus64DecoderStereo = opus_custom_decoder_create ( Opus64Mode, 2, &iOpusError ); // stereo decoder OPUS64
 
     // we require a constant bit rate
-    opus_custom_encoder_ctl ( OpusEncoderMono,     OPUS_SET_VBR ( 0 ) );
-    opus_custom_encoder_ctl ( OpusEncoderStereo,   OPUS_SET_VBR ( 0 ) );
-    opus_custom_encoder_ctl ( Opus64EncoderMono,   OPUS_SET_VBR ( 0 ) );
+    opus_custom_encoder_ctl ( OpusEncoderMono, OPUS_SET_VBR ( 0 ) );
+    opus_custom_encoder_ctl ( OpusEncoderStereo, OPUS_SET_VBR ( 0 ) );
+    opus_custom_encoder_ctl ( Opus64EncoderMono, OPUS_SET_VBR ( 0 ) );
     opus_custom_encoder_ctl ( Opus64EncoderStereo, OPUS_SET_VBR ( 0 ) );
 
     // for 64 samples frame size we have to adjust the PLC behavior to avoid loud artifacts
-    opus_custom_encoder_ctl ( Opus64EncoderMono,   OPUS_SET_PACKET_LOSS_PERC ( 35 ) );
+    opus_custom_encoder_ctl ( Opus64EncoderMono, OPUS_SET_PACKET_LOSS_PERC ( 35 ) );
     opus_custom_encoder_ctl ( Opus64EncoderStereo, OPUS_SET_PACKET_LOSS_PERC ( 35 ) );
 
     // we want as low delay as possible
-    opus_custom_encoder_ctl ( OpusEncoderMono,     OPUS_SET_APPLICATION ( OPUS_APPLICATION_RESTRICTED_LOWDELAY ) );
-    opus_custom_encoder_ctl ( OpusEncoderStereo,   OPUS_SET_APPLICATION ( OPUS_APPLICATION_RESTRICTED_LOWDELAY ) );
-    opus_custom_encoder_ctl ( Opus64EncoderMono,   OPUS_SET_APPLICATION ( OPUS_APPLICATION_RESTRICTED_LOWDELAY ) );
+    opus_custom_encoder_ctl ( OpusEncoderMono, OPUS_SET_APPLICATION ( OPUS_APPLICATION_RESTRICTED_LOWDELAY ) );
+    opus_custom_encoder_ctl ( OpusEncoderStereo, OPUS_SET_APPLICATION ( OPUS_APPLICATION_RESTRICTED_LOWDELAY ) );
+    opus_custom_encoder_ctl ( Opus64EncoderMono, OPUS_SET_APPLICATION ( OPUS_APPLICATION_RESTRICTED_LOWDELAY ) );
     opus_custom_encoder_ctl ( Opus64EncoderStereo, OPUS_SET_APPLICATION ( OPUS_APPLICATION_RESTRICTED_LOWDELAY ) );
 
     // set encoder low complexity for legacy 128 samples frame size
-    opus_custom_encoder_ctl ( OpusEncoderMono,   OPUS_SET_COMPLEXITY ( 1 ) );
+    opus_custom_encoder_ctl ( OpusEncoderMono, OPUS_SET_COMPLEXITY ( 1 ) );
     opus_custom_encoder_ctl ( OpusEncoderStereo, OPUS_SET_COMPLEXITY ( 1 ) );
 
-
     // Connections -------------------------------------------------------------
     // connections for the protocol mechanism
-    QObject::connect ( &Channel, &CChannel::MessReadyForSending,
-        this, &CClient::OnSendProtMessage );
+    QObject::connect ( &Channel, &CChannel::MessReadyForSending, this, &CClient::OnSendProtMessage );
 
-    QObject::connect ( &Channel, &CChannel::DetectedCLMessage,
-        this, &CClient::OnDetectedCLMessage );
+    QObject::connect ( &Channel, &CChannel::DetectedCLMessage, this, &CClient::OnDetectedCLMessage );
 
-    QObject::connect ( &Channel, &CChannel::ReqJittBufSize,
-        this, &CClient::OnReqJittBufSize );
+    QObject::connect ( &Channel, &CChannel::ReqJittBufSize, this, &CClient::OnReqJittBufSize );
 
-    QObject::connect ( &Channel, &CChannel::JittBufSizeChanged,
-        this, &CClient::OnJittBufSizeChanged );
+    QObject::connect ( &Channel, &CChannel::JittBufSizeChanged, this, &CClient::OnJittBufSizeChanged );
 
-    QObject::connect ( &Channel, &CChannel::ReqChanInfo,
-        this, &CClient::OnReqChanInfo );
+    QObject::connect ( &Channel, &CChannel::ReqChanInfo, this, &CClient::OnReqChanInfo );
 
-    QObject::connect ( &Channel, &CChannel::ConClientListMesReceived,
-        this, &CClient::ConClientListMesReceived );
+    QObject::connect ( &Channel, &CChannel::ConClientListMesReceived, this, &CClient::ConClientListMesReceived );
 
-    QObject::connect ( &Channel, &CChannel::Disconnected,
-        this, &CClient::Disconnected );
+    QObject::connect ( &Channel, &CChannel::Disconnected, this, &CClient::Disconnected );
 
-    QObject::connect ( &Channel, &CChannel::NewConnection,
-        this, &CClient::OnNewConnection );
+    QObject::connect ( &Channel, &CChannel::NewConnection, this, &CClient::OnNewConnection );
 
-    QObject::connect ( &Channel, &CChannel::ChatTextReceived,
-        this, &CClient::ChatTextReceived );
+    QObject::connect ( &Channel, &CChannel::ChatTextReceived, this, &CClient::ChatTextReceived );
 
-    QObject::connect ( &Channel, &CChannel::ClientIDReceived,
-        this, &CClient::OnClientIDReceived );
+    QObject::connect ( &Channel, &CChannel::ClientIDReceived, this, &CClient::OnClientIDReceived );
 
-    QObject::connect ( &Channel, &CChannel::MuteStateHasChangedReceived,
-        this, &CClient::MuteStateHasChangedReceived );
+    QObject::connect ( &Channel, &CChannel::MuteStateHasChangedReceived, this, &CClient::MuteStateHasChangedReceived );
 
-    QObject::connect ( &Channel, &CChannel::LicenceRequired,
-        this, &CClient::LicenceRequired );
+    QObject::connect ( &Channel, &CChannel::LicenceRequired, this, &CClient::LicenceRequired );
 
-    QObject::connect ( &Channel, &CChannel::VersionAndOSReceived,
-        this, &CClient::VersionAndOSReceived );
+    QObject::connect ( &Channel, &CChannel::VersionAndOSReceived, this, &CClient::VersionAndOSReceived );
 
-    QObject::connect ( &Channel, &CChannel::RecorderStateReceived,
-        this, &CClient::RecorderStateReceived );
+    QObject::connect ( &Channel, &CChannel::RecorderStateReceived, this, &CClient::RecorderStateReceived );
 
-    QObject::connect ( &ConnLessProtocol, &CProtocol::CLMessReadyForSending,
-        this, &CClient::OnSendCLProtMessage );
+    QObject::connect ( &ConnLessProtocol, &CProtocol::CLMessReadyForSending, this, &CClient::OnSendCLProtMessage );
 
-    QObject::connect ( &ConnLessProtocol, &CProtocol::CLServerListReceived,
-        this, &CClient::CLServerListReceived );
+    QObject::connect ( &ConnLessProtocol, &CProtocol::CLServerListReceived, this, &CClient::CLServerListReceived );
 
-    QObject::connect ( &ConnLessProtocol, &CProtocol::CLRedServerListReceived,
-        this, &CClient::CLRedServerListReceived );
+    QObject::connect ( &ConnLessProtocol, &CProtocol::CLRedServerListReceived, this, &CClient::CLRedServerListReceived );
 
-    QObject::connect ( &ConnLessProtocol, &CProtocol::CLConnClientsListMesReceived,
-        this, &CClient::CLConnClientsListMesReceived );
+    QObject::connect ( &ConnLessProtocol, &CProtocol::CLConnClientsListMesReceived, this, &CClient::CLConnClientsListMesReceived );
 
-    QObject::connect ( &ConnLessProtocol, &CProtocol::CLPingReceived,
-        this, &CClient::OnCLPingReceived );
+    QObject::connect ( &ConnLessProtocol, &CProtocol::CLPingReceived, this, &CClient::OnCLPingReceived );
 
-    QObject::connect ( &ConnLessProtocol, &CProtocol::CLPingWithNumClientsReceived,
-        this, &CClient::OnCLPingWithNumClientsReceived );
+    QObject::connect ( &ConnLessProtocol, &CProtocol::CLPingWithNumClientsReceived, this, &CClient::OnCLPingWithNumClientsReceived );
 
-    QObject::connect ( &ConnLessProtocol, &CProtocol::CLDisconnection ,
-        this, &CClient::OnCLDisconnection );
+    QObject::connect ( &ConnLessProtocol, &CProtocol::CLDisconnection, this, &CClient::OnCLDisconnection );
 
-    QObject::connect ( &ConnLessProtocol, &CProtocol::CLVersionAndOSReceived,
-        this, &CClient::CLVersionAndOSReceived );
+    QObject::connect ( &ConnLessProtocol, &CProtocol::CLVersionAndOSReceived, this, &CClient::CLVersionAndOSReceived );
 
-    QObject::connect ( &ConnLessProtocol, &CProtocol::CLChannelLevelListReceived,
-        this, &CClient::CLChannelLevelListReceived );
+    QObject::connect ( &ConnLessProtocol, &CProtocol::CLChannelLevelListReceived, this, &CClient::CLChannelLevelListReceived );
 
     // other
-    QObject::connect ( &Sound, &CSound::ReinitRequest,
-        this, &CClient::OnSndCrdReinitRequest );
+    QObject::connect ( &Sound, &CSound::ReinitRequest, this, &CClient::OnSndCrdReinitRequest );
 
-    QObject::connect ( &Sound, &CSound::ControllerInFaderLevel,
-        this, &CClient::OnControllerInFaderLevel );
+    QObject::connect ( &Sound, &CSound::ControllerInFaderLevel, this, &CClient::OnControllerInFaderLevel );
 
-    QObject::connect ( &Socket, &CHighPrioSocket::InvalidPacketReceived,
-        this, &CClient::OnInvalidPacketReceived );
+    QObject::connect ( &Sound, &CSound::ControllerInPanValue, this, &CClient::OnControllerInPanValue );
 
-    QObject::connect ( pSignalHandler, &CSignalHandler::HandledSignal,
-        this, &CClient::OnHandledSignal );
+    QObject::connect ( &Sound, &CSound::ControllerInFaderIsSolo, this, &CClient::OnControllerInFaderIsSolo );
+
+    QObject::connect ( &Sound, &CSound::ControllerInFaderIsMute, this, &CClient::OnControllerInFaderIsMute );
+
+    QObject::connect ( &Socket, &CHighPrioSocket::InvalidPacketReceived, this, &CClient::OnInvalidPacketReceived );
+
+    QObject::connect ( pSignalHandler, &CSignalHandler::HandledSignal, this, &CClient::OnHandledSignal );
 
     // start timer so that elapsed time works
     PreciseTime.start();
@@ -235,8 +212,7 @@ void CClient::OnSendProtMessage ( CVector<uint8_t> vecMessage )
     Socket.SendPacket ( vecMessage, Channel.GetAddress() );
 }
 
-void CClient::OnSendCLProtMessage ( CHostAddress     InetAddr,
-                                    CVector<uint8_t> vecMessage )
+void CClient::OnSendCLProtMessage ( CHostAddress InetAddr, CVector<uint8_t> vecMessage )
 {
     // the protocol queries me to call the function to send the message
     // send it through the network
@@ -255,14 +231,10 @@ void CClient::OnInvalidPacketReceived ( CHostAddress RecHostAddr )
     }
 }
 
-void CClient::OnDetectedCLMessage ( CVector<uint8_t> vecbyMesBodyData,
-                                    int              iRecID,
-                                    CHostAddress     RecHostAddr )
+void CClient::OnDetectedCLMessage ( CVector<uint8_t> vecbyMesBodyData, int iRecID, CHostAddress RecHostAddr )
 {
     // connection less messages are always processed
-    ConnLessProtocol.ParseConnectionLessMessageBody ( vecbyMesBodyData,
-                                                      iRecID,
-                                                      RecHostAddr );
+    ConnLessProtocol.ParseConnectionLessMessageBody ( vecbyMesBodyData, iRecID, RecHostAddr );
 }
 
 void CClient::OnJittBufSizeChanged ( int iNewJitBufSize )
@@ -293,8 +265,10 @@ void CClient::OnNewConnection()
     Channel.CreateReqConnClientsList();
     CreateServerJitterBufferMessage();
 
+    // clang-format off
 // TODO needed for compatibility to old servers >= 3.4.6 and <= 3.5.12
 Channel.CreateReqChannelLevelListMes();
+    // clang-format on
 }
 
 void CClient::CreateServerJitterBufferMessage()
@@ -313,8 +287,7 @@ void CClient::CreateServerJitterBufferMessage()
     }
 }
 
-void CClient::OnCLPingReceived ( CHostAddress InetAddr,
-                                 int          iMs )
+void CClient::OnCLPingReceived ( CHostAddress InetAddr, int iMs )
 {
     // make sure we are running and the server address is correct
     if ( IsRunning() && ( InetAddr == Channel.GetAddress() ) )
@@ -328,17 +301,13 @@ void CClient::OnCLPingReceived ( CHostAddress InetAddr,
     }
 }
 
-void CClient::OnCLPingWithNumClientsReceived ( CHostAddress InetAddr,
-                                               int          iMs,
-                                               int          iNumClients )
+void CClient::OnCLPingWithNumClientsReceived ( CHostAddress InetAddr, int iMs, int iNumClients )
 {
     // take care of wrap arounds (if wrapping, do not use result)
     const int iCurDiff = EvaluatePingMessage ( iMs );
     if ( iCurDiff >= 0 )
     {
-        emit CLPingTimeWithNumClientsReceived ( InetAddr,
-                                                iCurDiff,
-                                                iNumClients );
+        emit CLPingTimeWithNumClientsReceived ( InetAddr, iCurDiff, iNumClients );
     }
 }
 
@@ -363,9 +332,7 @@ void CClient::SetDoAutoSockBufSize ( const bool bValue )
     CreateServerJitterBufferMessage();
 }
 
-void CClient::SetRemoteChanGain ( const int   iId,
-                                  const float fGain,
-                                  const bool  bIsMyOwnFader )
+void CClient::SetRemoteChanGain ( const int iId, const float fGain, const bool bIsMyOwnFader )
 {
     // if this gain is for my own channel, apply the value for the Mute Myself function
     if ( bIsMyOwnFader )
@@ -379,8 +346,7 @@ void CClient::SetRemoteChanGain ( const int   iId,
 bool CClient::SetServerAddr ( QString strNAddr )
 {
     CHostAddress HostAddress;
-    if ( NetworkUtil().ParseNetworkAddress ( strNAddr,
-                                             HostAddress ) )
+    if ( NetworkUtil().ParseNetworkAddress ( strNAddr, HostAddress, bEnableIPv6 ) )
     {
         // apply address to the channel
         Channel.SetAddress ( HostAddress );
@@ -419,9 +385,7 @@ bool CClient::GetAndResetbJitterBufferOKFlag()
 void CClient::SetSndCrdPrefFrameSizeFactor ( const int iNewFactor )
 {
     // first check new input parameter
-    if ( ( iNewFactor == FRAME_SIZE_FACTOR_PREFERRED ) ||
-         ( iNewFactor == FRAME_SIZE_FACTOR_DEFAULT ) ||
-         ( iNewFactor == FRAME_SIZE_FACTOR_SAFE ) )
+    if ( ( iNewFactor == FRAME_SIZE_FACTOR_PREFERRED ) || ( iNewFactor == FRAME_SIZE_FACTOR_DEFAULT ) || ( iNewFactor == FRAME_SIZE_FACTOR_SAFE ) )
     {
         // init with new parameter, if client was running then first
         // stop it and restart again after new initialization
@@ -626,8 +590,7 @@ void CClient::OnSndCrdReinitRequest ( int iSndCrdResetType )
     {
         // in older QT versions, enums cannot easily be used in signals without
         // registering them -> workaroud: we use the int type and cast to the enum
-        const ESndCrdResetType eSndCrdResetType =
-            static_cast<ESndCrdResetType> ( iSndCrdResetType );
+        const ESndCrdResetType eSndCrdResetType = static_cast<ESndCrdResetType> ( iSndCrdResetType );
 
         // if client was running then first
         // stop it and restart again after new initialization
@@ -691,8 +654,7 @@ void CClient::OnHandledSignal ( int sigNum )
 #endif
 }
 
-void CClient::OnControllerInFaderLevel ( int iChannelIdx,
-                                         int iValue )
+void CClient::OnControllerInFaderLevel ( int iChannelIdx, int iValue )
 {
     // in case of a headless client the faders cannot be moved so we need
     // to send the controller information directly to the server
@@ -707,12 +669,46 @@ void CClient::OnControllerInFaderLevel ( int iChannelIdx,
     emit ControllerInFaderLevel ( iChannelIdx, iValue );
 }
 
+void CClient::OnControllerInPanValue ( int iChannelIdx, int iValue )
+{
+    // in case of a headless client the panners cannot be moved so we need
+    // to send the controller information directly to the server
+#ifdef HEADLESS
+    // channel index is valid
+    SetRemoteChanPan ( iChannelIdx, static_cast<float> ( iValue ) / AUD_MIX_PAN_MAX );
+#endif
+
+    emit ControllerInPanValue ( iChannelIdx, iValue );
+}
+
+void CClient::OnControllerInFaderIsSolo ( int iChannelIdx, bool bIsSolo )
+{
+    // in case of a headless client the buttons are not displayed so we need
+    // to send the controller information directly to the server
+#ifdef HEADLESS
+    // FIXME: no idea what to do here.
+#endif
+
+    emit ControllerInFaderIsSolo ( iChannelIdx, bIsSolo );
+}
+
+void CClient::OnControllerInFaderIsMute ( int iChannelIdx, bool bIsMute )
+{
+    // in case of a headless client the buttons are not displayed so we need
+    // to send the controller information directly to the server
+#ifdef HEADLESS
+    // FIXME: no idea what to do here.
+#endif
+
+    emit ControllerInFaderIsMute ( iChannelIdx, bIsMute );
+}
+
 void CClient::OnClientIDReceived ( int iChanID )
 {
     // for headless mode we support to mute our own signal in the personal mix
     // (note that the check for headless is done in the main.cpp and must not
     // be checked here)
-    if ( bNuteMeInPersonalMix )
+    if ( bMuteMeInPersonalMix )
     {
         SetRemoteChanGain ( iChanID, 0, false );
     }
@@ -751,8 +747,7 @@ void CClient::Stop()
         // that if the user initiates a connection and disconnection quickly
         // (e.g. quickly pressing enter five times), the software can get into
         // an unknown state
-        QCoreApplication::processEvents (
-            QEventLoop::ExcludeUserInputEvents, 100 );
+        QCoreApplication::processEvents ( QEventLoop::ExcludeUserInputEvents, 100 );
     }
 
     // Send disconnect message to server (Since we disable our protocol
@@ -774,14 +769,28 @@ void CClient::Init()
     const int iFraSizeDefault   = SYSTEM_FRAME_SIZE_SAMPLES * FRAME_SIZE_FACTOR_DEFAULT;
     const int iFraSizeSafe      = SYSTEM_FRAME_SIZE_SAMPLES * FRAME_SIZE_FACTOR_SAFE;
 
+#if defined( Q_OS_IOS )
+    bFraSiFactPrefSupported = true; // to reduce sound init time, because we know it's supported in iOS
+    bFraSiFactDefSupported  = true;
+    bFraSiFactSafeSupported = true;
+#else
     bFraSiFactPrefSupported = ( Sound.Init ( iFraSizePreffered ) == iFraSizePreffered );
-    bFraSiFactDefSupported  = ( Sound.Init ( iFraSizeDefault )   == iFraSizeDefault );
-    bFraSiFactSafeSupported = ( Sound.Init ( iFraSizeSafe )      == iFraSizeSafe );
+    bFraSiFactDefSupported  = ( Sound.Init ( iFraSizeDefault ) == iFraSizeDefault );
+    bFraSiFactSafeSupported = ( Sound.Init ( iFraSizeSafe ) == iFraSizeSafe );
+#endif
 
     // translate block size index in actual block size
     const int iPrefMonoFrameSize = iSndCrdPrefFrameSizeFactor * SYSTEM_FRAME_SIZE_SAMPLES;
 
     // get actual sound card buffer size using preferred size
+    // TODO - iOS needs 1 init only, now: 9 inits at launch <- slow
+    // Initially, I tried to fix this as follows (inside #ifdef ios tag):
+    //    if ( Sound.isInitialized )
+    //      iMonoBlockSizeSam = iPrefMonoFrameSize;
+    //    else
+    //      iMonoBlockSizeSam = Sound.Init ( iPrefMonoFrameSize );
+    // Problem is legitimate setting changes (buffer size for example).
+    // so the condition should be something like "if ( Sound.isInitialized and APP_IS_INIALIZING)"
     iMonoBlockSizeSam = Sound.Init ( iPrefMonoFrameSize );
 
     // Calculate the current sound card frame size factor. In case
@@ -827,7 +836,7 @@ void CClient::Init()
     }
     else
     {
-        if ( iMonoBlockSizeSam < DOUBLE_SYSTEM_FRAME_SIZE_SAMPLES  )
+        if ( iMonoBlockSizeSam < DOUBLE_SYSTEM_FRAME_SIZE_SAMPLES )
         {
             eAudioCompressionType = CT_OPUS64;
         }
@@ -835,8 +844,7 @@ void CClient::Init()
         {
             // since we use double size frame size for OPUS, we have to adjust the frame size factor
             iSndCrdFrameSizeFactor /= 2;
-            eAudioCompressionType   = CT_OPUS;
-
+            eAudioCompressionType = CT_OPUS;
         }
     }
 
@@ -853,9 +861,15 @@ void CClient::Init()
 
             switch ( eAudioQuality )
             {
-            case AQ_LOW:    iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_LOW_QUALITY_DBLE_FRAMESIZE;    break;
-            case AQ_NORMAL: iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_NORMAL_QUALITY_DBLE_FRAMESIZE; break;
-            case AQ_HIGH:   iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_HIGH_QUALITY_DBLE_FRAMESIZE;   break;
+            case AQ_LOW:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_LOW_QUALITY_DBLE_FRAMESIZE;
+                break;
+            case AQ_NORMAL:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_NORMAL_QUALITY_DBLE_FRAMESIZE;
+                break;
+            case AQ_HIGH:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_HIGH_QUALITY_DBLE_FRAMESIZE;
+                break;
             }
         }
         else
@@ -866,9 +880,15 @@ void CClient::Init()
 
             switch ( eAudioQuality )
             {
-            case AQ_LOW:    iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_LOW_QUALITY_DBLE_FRAMESIZE;    break;
-            case AQ_NORMAL: iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_NORMAL_QUALITY_DBLE_FRAMESIZE; break;
-            case AQ_HIGH:   iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_HIGH_QUALITY_DBLE_FRAMESIZE;   break;
+            case AQ_LOW:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_LOW_QUALITY_DBLE_FRAMESIZE;
+                break;
+            case AQ_NORMAL:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_NORMAL_QUALITY_DBLE_FRAMESIZE;
+                break;
+            case AQ_HIGH:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_HIGH_QUALITY_DBLE_FRAMESIZE;
+                break;
             }
         }
     }
@@ -884,9 +904,15 @@ void CClient::Init()
 
             switch ( eAudioQuality )
             {
-            case AQ_LOW:    iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_LOW_QUALITY;    break;
-            case AQ_NORMAL: iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_NORMAL_QUALITY; break;
-            case AQ_HIGH:   iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_HIGH_QUALITY;   break;
+            case AQ_LOW:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_LOW_QUALITY;
+                break;
+            case AQ_NORMAL:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_NORMAL_QUALITY;
+                break;
+            case AQ_HIGH:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_MONO_HIGH_QUALITY;
+                break;
             }
         }
         else
@@ -897,9 +923,15 @@ void CClient::Init()
 
             switch ( eAudioQuality )
             {
-            case AQ_LOW:    iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_LOW_QUALITY;    break;
-            case AQ_NORMAL: iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_NORMAL_QUALITY; break;
-            case AQ_HIGH:   iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_HIGH_QUALITY;   break;
+            case AQ_LOW:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_LOW_QUALITY;
+                break;
+            case AQ_NORMAL:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_NORMAL_QUALITY;
+                break;
+            case AQ_HIGH:
+                iCeltNumCodedBytes = OPUS_NUM_BYTES_STEREO_HIGH_QUALITY;
+                break;
             }
         }
     }
@@ -911,26 +943,17 @@ void CClient::Init()
     vecZeros.Init ( iStereoBlockSizeSam, 0 );
     vecsStereoSndCrdMuteStream.Init ( iStereoBlockSizeSam );
 
-    fMuteOutStreamGain = 1.0f;
-
     opus_custom_encoder_ctl ( CurOpusEncoder,
-                              OPUS_SET_BITRATE (
-                                  CalcBitRateBitsPerSecFromCodedBytes (
-                                      iCeltNumCodedBytes, iOPUSFrameSizeSamples ) ) );
+                              OPUS_SET_BITRATE ( CalcBitRateBitsPerSecFromCodedBytes ( iCeltNumCodedBytes, iOPUSFrameSizeSamples ) ) );
 
     // inits for network and channel
     vecbyNetwData.Init ( iCeltNumCodedBytes );
 
     // set the channel network properties
-    Channel.SetAudioStreamProperties ( eAudioCompressionType,
-                                       iCeltNumCodedBytes,
-                                       iSndCrdFrameSizeFactor,
-                                       iNumAudioChannels );
+    Channel.SetAudioStreamProperties ( eAudioCompressionType, iCeltNumCodedBytes, iSndCrdFrameSizeFactor, iNumAudioChannels );
 
     // init reverberation
-    AudioReverb.Init ( eAudioChannelConf,
-                       iStereoBlockSizeSam,
-                       SYSTEM_SAMPLE_RATE_HZ );
+    AudioReverb.Init ( eAudioChannelConf, iStereoBlockSizeSam, SYSTEM_SAMPLE_RATE_HZ );
 
     // init the sound card conversion buffers
     if ( bSndCrdConversionBufferRequired )
@@ -940,9 +963,9 @@ void CClient::Init()
         const int iSndCardStereoBlockSizeSamConvBuff = 2 * iSndCardMonoBlockSizeSamConvBuff;
         const int iConBufSize                        = iStereoBlockSizeSam + iSndCardStereoBlockSizeSamConvBuff;
 
-        SndCrdConversionBufferIn.Init  ( iConBufSize );
+        SndCrdConversionBufferIn.Init ( iConBufSize );
         SndCrdConversionBufferOut.Init ( iConBufSize );
-        vecDataConvBuf.Init            ( iStereoBlockSizeSam );
+        vecDataConvBuf.Init ( iStereoBlockSizeSam );
 
         // the output conversion buffer must be filled with the inner
         // block size for initialization (this is the latency which is
@@ -962,11 +985,13 @@ void CClient::AudioCallback ( CVector<int16_t>& psData, void* arg )
     // process audio data
     pMyClientObj->ProcessSndCrdAudioData ( psData );
 
+    // clang-format off
 /*
 // TEST do a soundcard jitter measurement
 static CTimingMeas JitterMeas ( 1000, "test2.dat" );
 JitterMeas.Measure();
 */
+    // clang-format on
 }
 
 void CClient::ProcessSndCrdAudioData ( CVector<int16_t>& vecsStereoSndCrd )
@@ -1005,21 +1030,27 @@ void CClient::ProcessAudioDataIntern ( CVector<int16_t>& vecsStereoSndCrd )
     int            i, j, iUnused;
     unsigned char* pCurCodedData;
 
-
     // Transmit signal ---------------------------------------------------------
+
+    if ( iInputBoost != 1 )
+    {
+        // apply a general gain boost to all audio input:
+        for ( i = 0, j = 0; i < iMonoBlockSizeSam; i++, j += 2 )
+        {
+            vecsStereoSndCrd[j + 1] = static_cast<int16_t> ( iInputBoost * vecsStereoSndCrd[j + 1] );
+            vecsStereoSndCrd[j]     = static_cast<int16_t> ( iInputBoost * vecsStereoSndCrd[j] );
+        }
+    }
+
     // update stereo signal level meter (not needed in headless mode)
 #ifndef HEADLESS
-    SignalLevelMeter.Update ( vecsStereoSndCrd,
-                              iMonoBlockSizeSam,
-                              true );
+    SignalLevelMeter.Update ( vecsStereoSndCrd, iMonoBlockSizeSam, true );
 #endif
 
     // add reverberation effect if activated
     if ( iReverbLevel != 0 )
     {
-        AudioReverb.Process ( vecsStereoSndCrd,
-                              bReverbOnLeftChan,
-                              static_cast<float> ( iReverbLevel ) / AUD_REVERB_MAX / 4 );
+        AudioReverb.Process ( vecsStereoSndCrd, bReverbOnLeftChan, static_cast<float> ( iReverbLevel ) / AUD_REVERB_MAX / 4 );
     }
 
     // apply pan (audio fader) and mix mono signals
@@ -1031,7 +1062,7 @@ void CClient::ProcessAudioDataIntern ( CVector<int16_t>& vecsStereoSndCrd )
         if ( eAudioChannelConf == CC_STEREO )
         {
             // for stereo only apply pan attenuation on one channel (same as pan in the server)
-            const float fGainL = MathUtils::GetLeftPan  ( fPan, false );
+            const float fGainL = MathUtils::GetLeftPan ( fPan, false );
             const float fGainR = MathUtils::GetRightPan ( fPan, false );
 
             for ( i = 0, j = 0; i < iMonoBlockSizeSam; i++, j += 2 )
@@ -1046,14 +1077,13 @@ void CClient::ProcessAudioDataIntern ( CVector<int16_t>& vecsStereoSndCrd )
         {
             // for mono implement a cross-fade between channels and mix them, for
             // mono-in/stereo-out use no attenuation in pan center
-            const float fGainL = MathUtils::GetLeftPan  ( fPan, eAudioChannelConf != CC_MONO_IN_STEREO_OUT );
+            const float fGainL = MathUtils::GetLeftPan ( fPan, eAudioChannelConf != CC_MONO_IN_STEREO_OUT );
             const float fGainR = MathUtils::GetRightPan ( fPan, eAudioChannelConf != CC_MONO_IN_STEREO_OUT );
 
             for ( i = 0, j = 0; i < iMonoBlockSizeSam; i++, j += 2 )
             {
                 // note that we need the Float2Short for stereo pan mode
-                vecsStereoSndCrd[i] = Float2Short (
-                    fGainL * vecsStereoSndCrd[j] + fGainR * vecsStereoSndCrd[j + 1] );
+                vecsStereoSndCrd[i] = Float2Short ( fGainL * vecsStereoSndCrd[j] + fGainR * vecsStereoSndCrd[j + 1] );
             }
         }
     }
@@ -1097,12 +1127,9 @@ void CClient::ProcessAudioDataIntern ( CVector<int16_t>& vecsStereoSndCrd )
         }
 
         // send coded audio through the network
-        Channel.PrepAndSendPacket ( &Socket,
-                                    vecCeltData,
-                                    iCeltNumCodedBytes );
+        Channel.PrepAndSendPacket ( &Socket, vecCeltData, iCeltNumCodedBytes );
     }
 
-
     // Receive signal ----------------------------------------------------------
     // in case of mute stream, store local data
     if ( bMuteOutStream )
@@ -1113,8 +1140,7 @@ void CClient::ProcessAudioDataIntern ( CVector<int16_t>& vecsStereoSndCrd )
     for ( i = 0; i < iSndCrdFrameSizeFactor; i++ )
     {
         // receive a new block
-        const bool bReceiveDataOk =
-            ( Channel.GetData ( vecbyNetwData, iCeltNumCodedBytes ) == GS_BUFFER_OK );
+        const bool bReceiveDataOk = ( Channel.GetData ( vecbyNetwData, iCeltNumCodedBytes ) == GS_BUFFER_OK );
 
         // get pointer to coded data and manage the flags
         if ( bReceiveDataOk )
@@ -1149,8 +1175,7 @@ void CClient::ProcessAudioDataIntern ( CVector<int16_t>& vecsStereoSndCrd )
     {
         for ( i = 0; i < iStereoBlockSizeSam; i++ )
         {
-            vecsStereoSndCrd[i] = Float2Short (
-                vecsStereoSndCrd[i] + vecsStereoSndCrdMuteStream[i] * fMuteOutStreamGain );
+            vecsStereoSndCrd[i] = Float2Short ( vecsStereoSndCrd[i] + vecsStereoSndCrdMuteStream[i] * fMuteOutStreamGain );
         }
     }
 
@@ -1182,21 +1207,18 @@ void CClient::ProcessAudioDataIntern ( CVector<int16_t>& vecsStereoSndCrd )
 
 int CClient::EstimatedOverallDelay ( const int iPingTimeMs )
 {
-    const float fSystemBlockDurationMs = static_cast<float> ( iOPUSFrameSizeSamples ) /
-        SYSTEM_SAMPLE_RATE_HZ * 1000;
+    const float fSystemBlockDurationMs = static_cast<float> ( iOPUSFrameSizeSamples ) / SYSTEM_SAMPLE_RATE_HZ * 1000;
 
     // If the jitter buffers are set effectively, i.e. they are exactly the
     // size of the network jitter, then the delay of the buffer is the buffer
     // length. Since that is usually not the case but the buffers are usually
     // a bit larger than necessary, we introduce some factor for compensation.
     // Consider the jitter buffer on the client and on the server side, too.
-    const float fTotalJitterBufferDelayMs = fSystemBlockDurationMs *
-        ( GetSockBufNumFrames() + GetServerSockBufNumFrames() ) * 0.7f;
+    const float fTotalJitterBufferDelayMs = fSystemBlockDurationMs * ( GetSockBufNumFrames() + GetServerSockBufNumFrames() ) * 0.7f;
 
     // consider delay introduced by the sound card conversion buffer by using
     // "GetSndCrdConvBufAdditionalDelayMonoBlSize()"
-    float fTotalSoundCardDelayMs = GetSndCrdConvBufAdditionalDelayMonoBlSize() *
-        1000.0f / SYSTEM_SAMPLE_RATE_HZ;
+    float fTotalSoundCardDelayMs = GetSndCrdConvBufAdditionalDelayMonoBlSize() * 1000.0f / SYSTEM_SAMPLE_RATE_HZ;
 
     // try to get the actual input/output sound card delay from the audio
     // interface, per definition it is not available if a 0 is returned
@@ -1210,9 +1232,7 @@ int CClient::EstimatedOverallDelay ( const int iPingTimeMs )
         // output, therefore we have "3 *" instead of "2 *" (for input and output)
         // the actual sound card buffer size
         // "GetSndCrdConvBufAdditionalDelayMonoBlSize"
-        fTotalSoundCardDelayMs +=
-            ( 3 * GetSndCrdActualMonoBlSize() ) *
-            1000.0f / SYSTEM_SAMPLE_RATE_HZ;
+        fTotalSoundCardDelayMs += ( 3 * GetSndCrdActualMonoBlSize() ) * 1000.0f / SYSTEM_SAMPLE_RATE_HZ;
     }
     else
     {
@@ -1222,17 +1242,13 @@ int CClient::EstimatedOverallDelay ( const int iPingTimeMs )
 
     // network packets are of the same size as the audio packets per definition
     // if no sound card conversion buffer is used
-    const float fDelayToFillNetworkPacketsMs =
-        GetSystemMonoBlSize() * 1000.0f / SYSTEM_SAMPLE_RATE_HZ;
+    const float fDelayToFillNetworkPacketsMs = GetSystemMonoBlSize() * 1000.0f / SYSTEM_SAMPLE_RATE_HZ;
 
     // OPUS additional delay at small frame sizes is half a frame size
     const float fAdditionalAudioCodecDelayMs = fSystemBlockDurationMs / 2;
 
     const float fTotalBufferDelayMs =
-        fDelayToFillNetworkPacketsMs +
-        fTotalJitterBufferDelayMs +
-        fTotalSoundCardDelayMs +
-        fAdditionalAudioCodecDelayMs;
+        fDelayToFillNetworkPacketsMs + fTotalJitterBufferDelayMs + fTotalSoundCardDelayMs + fAdditionalAudioCodecDelayMs;
 
     return MathUtils::round ( fTotalBufferDelayMs + iPingTimeMs );
 }
